@@ -32,13 +32,7 @@
 #  rep.timeDate              Replicates a 'timeDate' object
 ################################################################################
 
-# ---------------------------------------------------------------------------- #
-# Roxygen Tags
-#' @export
-# ---------------------------------------------------------------------------- #
-rep.timeDate <-
-    function(x, ...)
-{
+rep.timeDate <- function(x, ...) {
     # A function implemented by Diethelm Wuertz and Yohan Chalabi
 
     # Description:
@@ -66,4 +60,3 @@ rep.timeDate <-
 
 
 ################################################################################
-
