@@ -20,10 +20,7 @@
 #  unique.timeDate           Makes a 'timeDate' object unique
 ################################################################################
 
-
-unique.timeDate <-
-    function(x, ...)
-{
+unique.timeDate <- function(x, ...) {
     # A function Implemented by Diethelm Wuertz
 
     # Description:
@@ -42,4 +39,3 @@ unique.timeDate <-
 
 
 ################################################################################
-
