@@ -6,12 +6,12 @@
 #
 # This R package is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the 
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 # GNU Library General Public License for more details.
 #
-# You should have received a copy of the GNU Library General 
-# Public License along with this R package; if not, write to the 
-# Free Foundation, Inc., 59 Temple Place, Suite 330, Boston, 
+# You should have received a copy of the GNU Library General
+# Public License along with this R package; if not, write to the
+# Free Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 # MA  02111-1307  USA
 
 
@@ -21,60 +21,47 @@
 #  blockEnd                  Creates end dates for equally sized blocks
 ################################################################################
 
-# ---------------------------------------------------------------------------- #
-# Roxygen Tags
-#' @export
-# ---------------------------------------------------------------------------- #
-blockStart <- 
-    function(x, block = 20)
-{   
+blockStart <- function(x, block = 20) {
     # A function implemented by Diethelm Wuertz
 
     # Description:
     #   Computes start dates for numeric blocks of dates
-    
+
     # Example:
     #   blockEnd(timeSequence(), block = 30)
 
     # FUNCTION:
-    
+
     # Start Dates of Blocks:
     nx = length(as.character(x))
     fromIdx = seq(1, nx, by = block)
     from = x[fromIdx]
-    
+
     # Return Value:
     from
 }
 
 
-# ---------------------------------------------------------------------------- #
-# Roxygen Tags
-#' @export
-# ---------------------------------------------------------------------------- #
-blockEnd <- 
-    function(x, block = 20)
-{   
+blockEnd <- function(x, block = 20) {
     # A function implemented by Diethelm Wuertz
 
     # Description:
     #   Computes start dates for numeric blocks of dates
-    
+
     # Example:
     #   blockEnd(timeSequence(), block = 30)
 
     # FUNCTION:
-    
+
     # End Dates of Blocks:
     nx = length(as.character(x))
     fromIdx = seq(1, nx, by = block)
     toIdx = c(fromIdx[-1]-1, nx)
     to = x[toIdx]
-    
+
     # Return Value:
     to
 }
 
 
 ################################################################################
-
