@@ -16,29 +16,16 @@
 
 ################################################################################
 
-# ---------------------------------------------------------------------------- #
-# Roxygen Tags
-#' @export
-# ---------------------------------------------------------------------------- #
-setMethod("finCenter", "timeDate", 
-    function(x) 
-{
-    x@FinCenter
-}
-)
-   
+setMethod("finCenter", "timeDate",
+          function(x) {
+              x@FinCenter
+          })
 
-# ---------------------------------------------------------------------------- #
-# Roxygen Tags
-#' @export
-# ---------------------------------------------------------------------------- #    
-setMethod("finCenter<-", "timeDate", 
-    function(x, value) 
-{
-    x@FinCenter <- value; x
-}
-)
+setMethod("finCenter<-", "timeDate",
+          function(x, value) {
+              x@FinCenter <- value
+              x
+          })
 
 
 ################################################################################
-
